#ifndef CHIRP_ARRAY_H
#define CHIRP_ARRAY_H

#include "chirp_types.h"

/* create a new array at the given path, return zero on failure*/
struct chirp_array * chirp_array_create( const char * host, const char *path, int width, int height, int element_size,time_t stoptime);

/* open an existing array, return zero on failure */
struct chirp_array * chirp_array_open( const char * host, const char *path,time_t stoptime);

/* return the proprerties of this currently open array */
int chirp_array_width( struct chirp_array *a );
int chirp_array_height( struct chirp_array *a );
int chirp_array_element_size( struct chirp_array *a );

int  chirp_array_get_buffered( struct chirp_array *a, int i, int j, void *data,time_t stoptime);

/* get the indicated element and copy it to the pointer data */
int  chirp_array_get( struct chirp_array *a, int i, int j, void *data,time_t stoptime );

/* set the indicated element by copying it to the pointer data */
int  chirp_array_set( struct chirp_array *a, int i, int j, const void *data,time_t stoptime );

/* get the indicated row and copy it to the pointer data */
int chirp_array_get_row( struct chirp_array *a, int i, void *data,time_t stoptime );

/* get the indicated col and copy it to the pointer data */
int chirp_array_get_col( struct chirp_array *a, int i, void *data,time_t stoptime );

/* set the indicated row by copying it to the pointer data */
int  chirp_array_set_row( struct chirp_array *a, int i, const void *data,time_t stoptime );

/* set the indicated col by copying it to the pointer data */
int chirp_array_set_col( struct chirp_array *a, int i,const void *data,time_t stoptime );

/*delete a chirp array*/
int chirp_array_delete( struct chirp_array *a,time_t stoptime);

/* close this array and free all related resources */
void chirp_array_close( struct chirp_array *a,time_t stoptime );

#endif
